@@ -60,7 +60,6 @@ class GroupBy(Enum):
 
 @dataclass(frozen=True)
 class AnnotationCounterByTask(DataClassJsonMixin):
-    """"""
 
     task_id: str
     task_status: TaskStatus
@@ -73,8 +72,6 @@ class AnnotationCounterByTask(DataClassJsonMixin):
 
 @dataclass(frozen=True)
 class AnnotationCounterByInputData(DataClassJsonMixin):
-    """"""
-
     task_id: str
     task_status: TaskStatus
     task_phase: TaskPhase
@@ -399,6 +396,10 @@ class ListAnnotationCount(AbstractCommandLineInterface):
             task_counter = self.count_for_task(task_parser, target_attributes=target_attributes)
             task_counter_list.append(task_counter)
 
+        if len(task_counter_list) == 0:
+            logger.warning(f"集計対象のタスクが0件なので、ファイルを出力しません。")
+            return
+
         self.print_labels_count_for_task(task_counter_list, label_columns=target_label_columns, output_dir=output_dir)
 
         self.print_attributes_count_for_task(
@@ -436,6 +437,10 @@ class ListAnnotationCount(AbstractCommandLineInterface):
             input_data_counter = self.count_for_input_data(simple_annotation_dict, target_attributes=target_attributes)
             input_data_counter_list.append(input_data_counter)
 
+        if len(input_data_counter_list) == 0:
+            logger.warning(f"集計対象の入力データが0件なので、ファイルを出力しません。")
+            return
+
         self.print_labels_count_for_input_data(
             input_data_counter_list, label_columns=target_label_columns, output_dir=output_dir
         )
@@ -514,7 +519,7 @@ def parse_args(parser: argparse.ArgumentParser):
         "--task_query",
         type=str,
         help="集計対象タスクを絞り込むためのクエリ条件をJSON形式で指定します。使用できるキーは task_id, status, phase, phase_stage です。"
-        "`file://`を先頭に付けると、JSON形式のファイルを指定できます。",
+        " ``file://`` を先頭に付けると、JSON形式のファイルを指定できます。",
     )
     argument_parser.add_task_id(required=False)
 
@@ -528,10 +533,10 @@ def parse_args(parser: argparse.ArgumentParser):
         "--wait_options",
         type=str,
         help="アノテーションzipの更新が完了するまで待つ際のオプションを、JSON形式で指定してください。"
-        "`file://`を先頭に付けるとjsonファイルを指定できます。"
-        'デフォルは`{"interval":60, "max_tries":360}` です。'
-        "`interval`:完了したかを問い合わせる間隔[秒], "
-        "`max_tires`:完了したかの問い合わせを最大何回行うか。",
+        " ``file://`` を先頭に付けるとjsonファイルを指定できます。"
+        'デフォルは ``{"interval":60, "max_tries":360}`` です。'
+        "``interval`` :完了したかを問い合わせる間隔[秒], "
+        "``max_tires`` :完了したかの問い合わせを最大何回行うか。",
     )
 
     parser.set_defaults(subcommand_func=main)
@@ -543,9 +548,10 @@ def main(args):
     ListAnnotationCount(service, facade, args).main()
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
     subcommand_name = "list_annotation_count"
     subcommand_help = "各ラベル、各属性値のアノテーション数を出力します。"
     description = "各ラベル、各属性値のアノテーション数を、タスクごと/入力データごとに出力します。"
     parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description=description)
     parse_args(parser)
+    return parser
